==> statehub-k8s-helper-0.0.24.crate: statehub-k8s-helper-0.0.24/src/ext/policy_rule.rs <==
//
// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
// Use is subject to license terms.
//

use super::*;

pub trait PolicyRuleExt: Sized {
    fn new() -> Self;
    fn api_group(self, group: impl ToString) -> Self;
    fn api_groups(self, groups: impl IntoIterator<Item = impl ToString>) -> Self;
    fn resource(self, resource: impl ToString) -> Self;
    fn resources(self, resources: impl IntoIterator<Item = impl ToString>) -> Self;
    fn verb(self, verb: impl ToString) -> Self;
    fn verbs(self, verbs: impl IntoIterator<Item = impl ToString>) -> Self;
    fn all_resources(self) -> Self {
        self.resource("*")
    }
    fn all_verbs(self) -> Self {
        self.verb("*")
    }
}

impl PolicyRuleExt for rbacv1::PolicyRule {
    fn new() -> Self {
        Self::default()
    }

    fn api_group(self, group: impl ToString) -> Self {
        let api_groups = Some(vec![group.to_string()]);
        Self { api_groups, ..self }
    }

    fn api_groups(self, groups: impl IntoIterator<Item = impl ToString>) -> Self {
        let api_groups = Some(groups.into_iter().map(|group| group.to_string()).collect());
        Self { api_groups, ..self }
    }

    fn resource(self, resource: impl ToString) -> Self {
        let resources = Some(vec![resource.to_string()]);
        Self { resources, ..self }
    }

    fn resources(self, resources: impl IntoIterator<Item = impl ToString>) -> Self {
        let resources = Some(
            resources
                .into_iter()
                .map(|resource| resource.to_string())
                .collect(),
        );
        Self { resources, ..self }
    }

    fn verb(self, verb: impl ToString) -> Self {
        let verbs = vec![verb.to_string()];
        Self { verbs, ..self }
    }

    fn verbs(self, verbs: impl IntoIterator<Item = impl ToString>) -> Self {
        let verbs = verbs.into_iter().map(|verb| verb.to_string()).collect();
        Self { verbs, ..self }
    }
}

==> statehub-k8s-helper-0.0.31.crate: statehub-k8s-helper-0.0.31/src/ext/policy_rule.rs <==
//
// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
// Use is subject to license terms.
//

use super::*;

pub trait PolicyRuleExt: Sized {
    fn new<T: kube::Resource<DynamicType = ()>>() -> Self;
    fn api_group(self, group: impl ToString) -> Self;
    fn api_groups(self, groups: impl IntoIterator<Item = impl ToString>) -> Self;
    fn resource(self, resource: impl ToString) -> Self;
    fn resources(self, resources: impl IntoIterator<Item = impl ToString>) -> Self;
    fn verb(self, verb: impl ToString) -> Self;
    fn verbs(self, verbs: impl IntoIterator<Item = impl ToString>) -> Self;
    fn all_resources(self) -> Self {
        self.resource("*")
    }
    fn all_verbs(self) -> Self {
        self.verb("*")
    }
}

impl PolicyRuleExt for rbacv1::PolicyRule {
    fn new<T: kube::Resource<DynamicType = ()>>() -> Self {
        Self::default()
            .api_group(T::group(&()))
            .resource(T::plural(&()))
    }

    fn api_group(self, group: impl ToString) -> Self {
        let api_groups = Some(vec![group.to_string()]);
        Self { api_groups, ..self }
    }

    fn api_groups(self, groups: impl IntoIterator<Item = impl ToString>) -> Self {
        let api_groups = Some(groups.into_iter().map(|group| group.to_string()).collect());
        Self { api_groups, ..self }
    }

    fn resource(self, resource: impl ToString) -> Self {
        let resources = Some(vec![resource.to_string()]);
        Self { resources, ..self }
    }

    fn resources(self, resources: impl IntoIterator<Item = impl ToString>) -> Self {
        let resources = Some(
            resources
                .into_iter()
                .map(|resource| resource.to_string())
                .collect(),
        );
        Self { resources, ..self }
    }

    fn verb(self, verb: impl ToString) -> Self {
        let verbs = vec![verb.to_string()];
        Self { verbs, ..self }
    }

    fn verbs(self, verbs: impl IntoIterator<Item = impl ToString>) -> Self {
        let verbs = verbs.into_iter().map(|verb| verb.to_string()).collect();
        Self { verbs, ..self }
    }
}
